#
# spec file for package zpaq
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define         soname   lib%{name}
%define         sover    0.1
%define         sonum    0_1
%define         dversion 713
Name:           zpaq
Version:        7.13
Release:        15.1
Summary:        A journaling, incremental, deduplicating archiver for Windows and Linux
License:        SUSE-Public-Domain and MIT
Group:          Productivity/Archiving/Compression
Url:            http://mattmahoney.net/dc/zpaq.html
Source0:        http://mattmahoney.net/dc/zpaq%{dversion}.zip
Source1:        %{name}.changes
BuildRequires:  dos2unix
BuildRequires:  gcc-c++
BuildRequires:  unzip
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
zpaq is a journaling, incremental, deduplicating archiver for Windows and
Linux. "Journaling" means that when you update a file or directory, both
the old and new versions are saved. You can extract from the archive as it
existed at any time in the past. "Incremental", means that when you back up
your entire hard drive, for example:

  zpaq -add e:backup.zpaq c:\*

that only those files whose last-modified date has changed since the
previous backup are added. For 100 GB of files, this typically takes 1-2
minutes, vs. a few hours to create the first version. "Deduplicating" means
that identical files or fragments are stored only once to save time and
space.

%package -n %{soname}%{sonum}
Summary:        Shared library for zpaq
Group:          System/Libraries

%description -n %{soname}%{sonum}
zpaq is a journaling, incremental, deduplicating archiver for Windows and
Linux. "Journaling" means that when you update a file or directory, both
the old and new versions are saved. You can extract from the archive as it
existed at any time in the past. "Incremental", means that when you back up
your entire hard drive, for example:

  zpaq -add e:backup.zpaq c:\*

that only those files whose last-modified date has changed since the
previous backup are added. For 100 GB of files, this typically takes 1-2
minutes, vs. a few hours to create the first version. "Deduplicating" means
that identical files or fragments are stored only once to save time and
space.

This package contains shared library

%package        devel
Summary:        Development files for zpaq
Group:          Development/Languages/C and C++
Requires:       %{soname}%{sonum} = %{version}-%{release}
Provides:       %{soname}-devel = %{version}
Obsoletes:      %{soname}-devel < %{version}

%description devel
zpaq is a journaling, incremental, deduplicating archiver for Windows and
Linux. "Journaling" means that when you update a file or directory, both
the old and new versions are saved. You can extract from the archive as it
existed at any time in the past. "Incremental", means that when you back up
your entire hard drive, for example:

  zpaq -add e:backup.zpaq c:\*

that only those files whose last-modified date has changed since the
previous backup are added. For 100 GB of files, this typically takes 1-2
minutes, vs. a few hours to create the first version. "Deduplicating" means
that identical files or fragments are stored only once to save time and
space.

This package contains development files

%prep
%setup -q -c %{name}%{dversion}
dos2unix readme.txt COPYING
# remove date and time from binary
modified="$(sed -n '/^----/n;s/ - .*$//;p;q' "%{SOURCE1}")"
DATE="\"$(date -d "${modified}" "+%%b %%e %%Y")\""
TIME="\"$(date -d "${modified}" "+%%R")\""
find .  -name '*.cpp' |\
    xargs sed -i "s/__DATE__/${DATE}/g;s/__TIME__/${TIME}/g"

%build
make %{?_smp_mflags} CXXFLAGS="%{optflags}"

%install
make \
  install \
  DESTDIR="%{?buildroot}" \
  LIBDIR="%{_libdir}" \
  BINDIR="%{_bindir}" \
  MANDIR="%{_mandir}" \
  INCLUDEDIR="%{_includedir}" \

%post -n %{soname}%{sonum} -p /sbin/ldconfig
%postun -n %{soname}%{sonum} -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%doc COPYING readme.txt
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{ext_man}

%files -n %{soname}%{sonum}
%defattr(-,root,root,-)
%doc COPYING
%{_libdir}/%{soname}.so.%{sover}

%files  devel
%defattr(-,root,root,-)
%doc COPYING
%{_libdir}/%{soname}.so
%{_includedir}/%{soname}.h

%changelog
* Sun Oct 23 2016 mpluskal@suse.com
- Small package cleanup and rename of devel package
* Sat May  7 2016 mpluskal@suse.com
- Update to 7.13
  * Removes requirement for separate  WinXP version. Fixes Intel
    and VS 2015 compiler errors.
  * Removes multi-part archive support, -nodelete, add -test, and
  - key prompt.
  * Updated Makefile to link libzpaq.o statically.
  * Fixes bug in extracting streaming archive with empty first
    file name.
  * Adds multi-part archives, -index. Some UI changes. Updates
    libzpaq.h, zpaq.pod.
  * Adds -repack, -encrypt. Updates libzpaq.cpp, zpaq.pod
  * Faster extract. Removes -encrypt (combined with -repack).
    Updates libzpaq.h, zpaq.pod. Apr. 29, 2016: added
    zpaq-gcc481.exe for older machines.
  * Adds support for sparse files in Windows.
* Sat Mar 19 2016 mpluskal@suse.com
- Update to version 7.07
  * Fixes v7.06 bug in creating multipart encrypted archives with
    incorrectly salted index
- Changes for 7.06
  * Fixes handling of some corrupted archives. Conforms to new spec
    zpaq205.pdf. New man page, Makefile, COPYING
- Ship shared library and devel package as well
- Various spec file improvements
* Sun Jan  3 2016 p.drouand@gmail.com
- Update to version 7.05
  * Fixed -method 111
  * fixes a valgrind warning (LZ77 read past end of input).
* Fri Apr 17 2015 mpluskal@suse.com
- Initial changelog for version 7.04
- Do not include build date and time
